/*
 * Project name:
     Force click
 * Copyright:
     (c) Mikroelektronika, 2016.
 * Revision History:
     20160523:
       - initial release (AM);
 * Description:
      Example is written to show you how you can use the Force click.
      Pressing the Flex surface you are changing the resistance of the click
      ADC results is displayed on the LCD.
 * Test configuration:
     MCU:             ATMEGA32
                      http://www.atmel.com/Images/doc2503.pdf
     Dev.board:       EasyAVR v7
                      http://www.mikroe.com/easyavr/
     Oscillator:      External Clock 8.0000 MHz
     Ext. Modules:    LCD display 2x16, Force click
                      http://www.mikroe.com/store/components/various/
     SW:              mikroC PRO for AVR
                      http://www.mikroe.com/mikroc/avr/
 * NOTES:
     - Turn on Lcd backlight switch SW3.1 (board specific)
     - Place the Force click to the mikroBUS 1

 */
 
#include <built_in.h>

// Lcd module connections
sbit LCD_RS at PORTA2_bit;
sbit LCD_EN at PORTD6_bit;
sbit LCD_D4 at PORTC4_bit;
sbit LCD_D5 at PORTC5_bit;
sbit LCD_D6 at PORTC6_bit;
sbit LCD_D7 at PORTC7_bit;

sbit LCD_RS_Direction at DDA2_bit;
sbit LCD_EN_Direction at DDD6_bit;
sbit LCD_D4_Direction at DDC4_bit;
sbit LCD_D5_Direction at DDC5_bit;
sbit LCD_D6_Direction at DDC6_bit;
sbit LCD_D7_Direction at DDC7_bit;
// End Lcd module connections


// Declare Variables
 char txt1[] = "Force Click Demo";
 char txt2[] = "Value:         V";
 char txt[6] = {0};
 unsigned int adc_rd;

 const double Vadc_5  = 4.8828125;       // ADC step 5V/1024 4,88mV (10bit ADC)
 const double Vadc_33 = 3.2226562;       // ADC step 3,3V/1024 3,22mV (10bit ADC)

//Read sensor
void ReadSensor() {
  adc_rd = ADC_Get_Sample(7);            // Read PA7
  Delay_ms(100);                          // Pause 10ms
}

void main() {

  DDA7_bit = 0;                          // Set PA7 as input   jok!
  ADC_Init();                            // Initialize ADC
  Delay_ms(100);                         // Pause of 100ms for ADC module stabilization

  Lcd_Init();                            // Initialize Lcd

  Lcd_Cmd(_LCD_CLEAR);                   // Clear display
  Lcd_Cmd(_LCD_CURSOR_OFF);              // Cursor off

  Lcd_Out(1,1,txt1);                     // Write text in first row
  Lcd_Out(2,1,txt2);                     // Write text in second row

  Delay_ms(1000);                        // Small delay

  while (1) {

    ReadSensor();

    adc_rd = (adc_rd * Vadc_33);         // volatage input and resolution
                                         // 3.226 = 3300/1023
    FloatToStr(adc_rd, txt);             // Convert adc reading to text string
    txt[4] = 0;                          // Cut all the numbers after the char 5

    Lcd_Out(2,8,txt);                    // Write text in second row
    Delay_ms(200);
  }
}